[Numpy-svn] r3457 - trunk/numpy

numpy-svn at scipy.org numpy-svn at scipy.org
Tue Nov 21 12:13:16 EST 2006


Author: cookedm
Date: 2006-11-21 11:13:14 -0600 (Tue, 21 Nov 2006)
New Revision: 3457

Modified:
   trunk/numpy/add_newdocs.py
Log:
better doc for a.dump and a.dumps

Modified: trunk/numpy/add_newdocs.py
===================================================================
--- trunk/numpy/add_newdocs.py	2006-11-20 21:24:20 UTC (rev 3456)
+++ trunk/numpy/add_newdocs.py	2006-11-21 17:13:14 UTC (rev 3457)
@@ -771,8 +771,10 @@
 
 
 add_newdoc('numpy.core.multiarray', 'ndarray', ('dump',
     """a.dump(file) Dump to specified file.
 
+    The array can be read back with pickle.load or numpy.load
+
     Arguments:
         file -- string naming the dump file.
 
@@ -780,8 +782,9 @@
 
 
 add_newdoc('numpy.core.multiarray', 'ndarray', ('dumps',
-    """a.dumps() -> string containing the dump?
+    """a.dumps() returns the pickle of the array as a string.
 
+    pickle.loads or numpy.loads will convert the string back to an array.
     """))
 
 
@@ -771,8 +771,10 @@
 
 add_newdoc('numpy.core.multiarray', 'ndarray', ('dump',
-    """a.dump(file) Dump to specified file.
+    """a.dump(file) Dump a pickle of the array to the specified file.
 




More information about the Numpy-svn mailing list